@@ -12,3 +12,6 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+
+from easytransfer import layers
+from easytransfer.engines.model import base_model, Config, FLAGS
\ No newline at end of file
